@@ -1,5 +1,6 @@
 import argparse
 import os
+from typing import Type, Any
 
 
 def init_cli():
@@ -9,19 +10,14 @@ def init_cli():
     parser = argparse.ArgumentParser()
 
     # config
-    parser.add_argument('config', type=str, help='Configuration file', nargs='?', default=os.environ.get('CONFIG'))
+    parser.add_argument("config", type=str, help="Configuration file")
 
     # logging
-    parser.add_argument('--log-level', type=str, choices=['critical', 'error', 'warning', 'info', 'debug'],
-                        default=os.environ.get('PYOBS_LOG_LEVEL', 'info'))
-    parser.add_argument('-l', '--log-file', type=str, help='file to write log into',
-                        default=os.environ.get('PYOBS_LOG_FILE'))
-    parser.add_argument('--log-rotate', action='store_true', help='rotate logs automatically',
-                        default=os.environ.get('PYOBS_LOG_ROTATE') in ['yes', 'true'])
+    parser.add_argument("--log-level", type=str, choices=["critical", "error", "warning", "info", "debug"])
+    parser.add_argument("-l", "--log-file", type=str, help="file to write log into")
 
     # debug stuff
-    parser.add_argument('--debug-time', type=str, help='Fake time at start for pyobs to use',
-                        default=os.environ.get('PYOBS_DEBUG_TIME'))
+    parser.add_argument("--debug-time", type=str, help="Fake time at start for pyobs to use")
 
     # return it
     return parser
@@ -47,7 +43,7 @@ def parse_cli(parser: argparse.ArgumentParser):
     return vars(args)
 
 
-def start_daemon(app_class, pid_file=None, *args, **kwargs):
+def start_daemon(app_class, pid_file=None, **kwargs: Any) -> None:
     """Start process as a daemon.
 
     Args:
@@ -62,13 +58,12 @@ def start_daemon(app_class, pid_file=None, *args, **kwargs):
 
     # This launches the daemon in its context
     with daemon.DaemonContext(
-            working_directory=run_dir,
-            umask=0o002,
-            pidfile=pidfile.TimeoutPIDLockFile(pid_file)) as context:
-        run(*args, app_class=app_class, **kwargs)
+        working_directory=run_dir, umask=0o002, pidfile=pidfile.TimeoutPIDLockFile(pid_file)
+    ) as context:
+        run(app_class, **kwargs)
 
 
-def run(app_class, **kwargs):
+def run(app_class: Type, **kwargs: Any) -> None:
     """Run a pyobs application with the given options.
 
     Args:
@@ -80,22 +75,22 @@ def run(app_class, **kwargs):
     app.run()
 
 
-def main():
+def main() -> None:
     from pyobs.application import Application
 
     # init argument parsing and add PID/Daemon stuff
     parser = init_cli()
-    parser.add_argument('-p', '--pid-file', type=str, default=os.environ.get('PIDFILE'))
+    parser.add_argument("-p", "--pid-file", type=str)
 
     # parse it
     args = parse_cli(parser)
 
     # run app
-    if args['pid_file']:
+    if args["pid_file"]:
         start_daemon(app_class=Application, **args)
     else:
         run(app_class=Application, **args)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
