@@ -1,10 +1,10 @@
-from typing import Tuple, Dict, List
+from typing import Tuple, Dict, List, Optional, Any
 
 import numpy as np
 import logging
 from scipy import ndimage
 
-from .base import FocusSeries
+from pyobs.utils.focusseries.base import FocusSeries
 from pyobs.utils.curvefit import fit_hyperbola
 from pyobs.images import Image
 
@@ -14,9 +14,10 @@ log = logging.getLogger(__name__)
 
 class ProjectionFocusSeries(FocusSeries):
     """Focus series from projected x/y."""
-    __module__ = 'pyobs.utils.focusseries'
 
-    def __init__(self, backsub: bool = True, xbad: list = None, ybad: list = None):
+    __module__ = "pyobs.utils.focusseries"
+
+    def __init__(self, backsub: bool = True, xbad: Optional[List[int]] = None, ybad: Optional[List[int]] = None):
         """Initialize a new projection focus series.
 
         Args:
@@ -33,11 +34,11 @@ class ProjectionFocusSeries(FocusSeries):
         self._ybad = ybad
         self._data: List[Dict[str, float]] = []
 
-    def reset(self):
+    def reset(self) -> None:
         """Reset focus series."""
         self._data = []
 
-    def analyse_image(self, image: Image):
+    def analyse_image(self, image: Image) -> None:
         """Analyse given image.
 
         Args:
@@ -45,6 +46,8 @@ class ProjectionFocusSeries(FocusSeries):
         """
 
         # clean data
+        if image.data is None:
+            return
         data = self._clean(image.data)
 
         # get projections
@@ -66,8 +69,8 @@ class ProjectionFocusSeries(FocusSeries):
         yavg = np.average(yclean)
         x = xwind * (xclean - xavg) / xavg
         y = ywind * (yclean - yavg) / yavg
-        xcorr = np.correlate(x, x, mode='same')
-        ycorr = np.correlate(y, y, mode='same')
+        xcorr = np.correlate(x, x, mode="same")
+        ycorr = np.correlate(y, y, mode="same")
 
         # filter out the peak (e.g. cosmics, ...)
         # imx = np.argmax(xcorr)
@@ -80,14 +83,24 @@ class ProjectionFocusSeries(FocusSeries):
         yfit = self._fit_correlation(ycorr)
 
         # log it
-        log.info('Found x=%.1f+-%.1f and y=%.1f+-%.1f.',
-                 xfit.params['fwhm'].value, xfit.params['fwhm'].stderr,
-                 yfit.params['fwhm'].value, yfit.params['fwhm'].stderr)
+        log.info(
+            "Found x=%.1f+-%.1f and y=%.1f+-%.1f.",
+            xfit.params["fwhm"].value,
+            xfit.params["fwhm"].stderr,
+            yfit.params["fwhm"].value,
+            yfit.params["fwhm"].stderr,
+        )
 
         # add to list
-        self._data.append({'focus': float(image.header['TEL-FOCU']),
-                           'x': float(xfit.params['fwhm'].value), 'xerr': float(xfit.params['fwhm'].stderr),
-                           'y': float(yfit.params['fwhm'].value), 'yerr': float(yfit.params['fwhm'].stderr)})
+        self._data.append(
+            {
+                "focus": float(image.header["TEL-FOCU"]),
+                "x": float(xfit.params["fwhm"].value),
+                "xerr": float(xfit.params["fwhm"].stderr),
+                "y": float(yfit.params["fwhm"].value),
+                "yerr": float(yfit.params["fwhm"].stderr),
+            }
+        )
 
     def fit_focus(self) -> Tuple[float, float]:
         """Fit focus from analysed images
@@ -97,11 +110,11 @@ class ProjectionFocusSeries(FocusSeries):
         """
 
         # get data
-        focus = [d['focus'] for d in self._data]
-        xfwhm = [d['x'] for d in self._data]
-        xsig = [d['xerr'] for d in self._data]
-        yfwhm = [d['y'] for d in self._data]
-        ysig = [d['yerr'] for d in self._data]
+        focus = [d["focus"] for d in self._data]
+        xfwhm = [d["x"] for d in self._data]
+        xsig = [d["xerr"] for d in self._data]
+        yfwhm = [d["y"] for d in self._data]
+        ysig = [d["yerr"] for d in self._data]
 
         # fit focus
         try:
@@ -111,10 +124,10 @@ class ProjectionFocusSeries(FocusSeries):
             # weighted mean
             xerr = np.sqrt(xerr)
             yerr = np.sqrt(yerr)
-            foc = (xfoc / xerr + yfoc / yerr) / (1. / xerr + 1. / yerr)
-            err = 2. / (1. / xerr + 1. / yerr)
+            foc = (xfoc / xerr + yfoc / yerr) / (1.0 / xerr + 1.0 / yerr)
+            err = 2.0 / (1.0 / xerr + 1.0 / yerr)
         except (RuntimeError, RuntimeWarning):
-            raise ValueError('Could not find best focus.')
+            raise ValueError("Could not find best focus.")
 
         # get min and max foci
         min_focus = np.min(focus)
@@ -126,7 +139,7 @@ class ProjectionFocusSeries(FocusSeries):
         return float(foc), float(err)
 
     @staticmethod
-    def _window_function(arr, border=0):
+    def _window_function(arr: np.ndarray, border: int = 0) -> np.ndarray:
         """
         Creates a sine window function of the same size as some 1-D array "arr".
         Optionally, a zero border at the edges is added by "scrunching" the window.
@@ -135,11 +148,13 @@ class ProjectionFocusSeries(FocusSeries):
         nwind = ndata - 2 * border
         w = np.zeros(ndata)
         for i in range(nwind):
-            w[i + border] = np.sin(np.pi * (i + 1.) / (nwind + 1.))
+            w[i + border] = np.sin(np.pi * (i + 1.0) / (nwind + 1.0))
         return w
 
     @staticmethod
-    def _clean(data, backsub=True, xbad=None, ybad=None):
+    def _clean(
+        data: np.ndarray, backsub: bool = True, xbad: Optional[np.ndarray] = None, ybad: Optional[np.ndarray] = None
+    ) -> np.ndarray:
         """
         Removes global slopes and fills up bad rows (ybad) or columns (xbad).
         """
@@ -180,7 +195,7 @@ class ProjectionFocusSeries(FocusSeries):
             return data
 
     @staticmethod
-    def _fit_correlation(correl):
+    def _fit_correlation(correl: np.ndarray) -> Any:
         from lmfit.models import GaussianModel
 
         # create Gaussian model
@@ -189,10 +204,10 @@ class ProjectionFocusSeries(FocusSeries):
         # initial guess
         x = np.arange(len(correl))
         pars = model.guess(correl, x=x)
-        pars['sigma'].value = 20.
+        pars["sigma"].value = 20.0
 
         # fit
         return model.fit(correl, pars, x=x)
 
 
-__all__ = ['ProjectionFocusSeries']
+__all__ = ["ProjectionFocusSeries"]
